@@ -15,12 +15,14 @@ from docly.ioutils import (is_dir,
                            check_out_path,
                            process_file,
                            is_python_file,
+                           is_ipynb_notebook,
                            query_yes_no,
                            look_for_update
                            )
 from docly.ioutils.console_printer import print_on_console
 from docly.ioutils.apply_diff import apply_diff
 from docly.ioutils.table_printer import print_results_as_table
+from docly.ioutils.convert_ipynb import convert_ipynb_to_python
 from docly.logic.logic_main import load_model, predict_docstring
 
 transformers.logger.setLevel(transformers.logging.CRITICAL)
@@ -47,13 +49,13 @@ def _print_welcome():
 #     print(docstrs)
 
 
-def _apply_diff(docstr_loc, no_generate_args_list):
+def _apply_diff(docstr_loc, no_generate_args_list, ipynb_files):
     print_on_console("Applying diff", color="green")
-    apply_diff(docstr_loc, no_generate_args_list)
+    apply_diff(docstr_loc, no_generate_args_list, ipynb_files)
     print_on_console("Diff applied. Good bye!", color="green", emoji="thumbsup")
 
 
-def _deal_with_result(args, table_rows, docstr_loc):
+def _deal_with_result(args, table_rows, docstr_loc, ipynb_files):
     if not args.no_generate_diff and table_rows:
         print_results_as_table(table_rows)
     elif args.no_generate_diff and docstr_loc:
@@ -68,7 +70,7 @@ def _deal_with_result(args, table_rows, docstr_loc):
             choice = query_yes_no("Do you want to apply the suggestions?")
         
         if choice:
-            _apply_diff(docstr_loc, args.no_generate_args_list)
+            _apply_diff(docstr_loc, args.no_generate_args_list, ipynb_files)
         else:
             print_on_console("Nothing changed. Good bye!", color="green", emoji="thumbsup")
     else:
@@ -77,8 +79,12 @@ def _deal_with_result(args, table_rows, docstr_loc):
 
 @Halo(text='Processing files', spinner='dots')
 def _process(args, model, tokenizer, ts_lib_path, config: DoclyConfig):
+    """
+    Terribly written code. Refactor ASAP
+    """
     table_rows = []
     docstr_loc = {}  # Very badly named variable. Need to change
+    ipynb_files = {}
 
     for file in args.files:
         f_path = Path(file)
@@ -93,14 +99,36 @@ def _process(args, model, tokenizer, ts_lib_path, config: DoclyConfig):
                             if ds == "":
                                 docstr = predict_docstring(model, tokenizer, [code_tokens])
                                 if docstr_loc.get(str(f)) is None:
-                                    docstr_loc[str(f)] = {start_index[0]: (start_index[1], 
-                                                                        docstr[0], 
-                                                                        params)}
+                                    docstr_loc[str(f)] = {start_index[0]: 
+                                                                (start_index[1], 
+                                                                docstr[0], 
+                                                                params
+                                                                )
+                                                         }
                                 else:
                                     docstr_loc[str(f)][start_index[0]] = (start_index[1], 
-                                                                        docstr[0],
-                                                                        params)
+                                                                          docstr[0],
+                                                                          params)
                                 table_rows.append([f.name, function_name, docstr[0]])
+                elif not is_dir(f) and is_ipynb_notebook(f) and args.run_on_notebooks:
+                    if not config.is_dir_skipped(str(f).split("/")[:-1]):
+                        py_file = convert_ipynb_to_python(f)
+                        for code_tokens, params, start_index, function_name, ds in process_file(py_file, ts_lib_path):
+                            if ds == "":
+                                docstr = predict_docstring(model, tokenizer, [code_tokens])
+                                if docstr_loc.get(str(py_file)) is None:
+                                        docstr_loc[str(py_file)] = {start_index[0]: 
+                                                                        (start_index[1], 
+                                                                        docstr[0], 
+                                                                        params
+                                                                        )
+                                                                    }
+                                else:
+                                    docstr_loc[str(py_file)][start_index[0]] = (start_index[1], 
+                                                                                docstr[0],
+                                                                                params)
+                                table_rows.append([f.name, function_name, docstr[0]])
+                                ipynb_files[str(py_file.absolute())] = f
         else:
             if is_python_file(f_path):
                 if not config.is_dir_skipped(str(f_path.absolute()).split("/")[:-1]):
@@ -109,15 +137,36 @@ def _process(args, model, tokenizer, ts_lib_path, config: DoclyConfig):
                             docstr = predict_docstring(model, tokenizer, [code_tokens])
                             if docstr_loc.get(str(f_path.absolute())) is None:
                                 docstr_loc[str(f_path.absolute())] = {start_index[0]: 
-                                                                    (start_index[1], 
-                                                                    docstr[0],
-                                                                    params)}
+                                                                        (start_index[1], 
+                                                                        docstr[0],
+                                                                        params
+                                                                        )
+                                                                     }
                             else:
                                 docstr_loc[str(f_path.absolute())][start_index[0]] = (start_index[1], 
                                                                                     docstr[0],
                                                                                     params)
                             table_rows.append([f_path.name, function_name, docstr[0]])
-    return table_rows, docstr_loc
+            elif is_ipynb_notebook(f_path) and args.run_on_notebooks:
+                if not config.is_dir_skipped(str(f_path.absolute()).split("/")[:-1]):
+                    py_file = convert_ipynb_to_python(f_path)
+                    for code_tokens, params, start_index, function_name, ds in process_file(py_file, ts_lib_path):
+                        if ds == "":
+                            docstr = predict_docstring(model, tokenizer, [code_tokens])
+                            if docstr_loc.get(str(py_file)) is None:
+                                    docstr_loc[str(py_file)] = {start_index[0]: 
+                                                                    (start_index[1], 
+                                                                    docstr[0],
+                                                                    params
+                                                                    )
+                                                                }
+                            else:
+                                docstr_loc[str(py_file)][start_index[0]] = (start_index[1], 
+                                                                            docstr[0],
+                                                                            params)
+                            table_rows.append([f_path.name, function_name, docstr[0]])
+                            ipynb_files[str(py_file.absolute())] = f_path.absolute()
+    return table_rows, docstr_loc, ipynb_files
 
 
 
@@ -128,6 +177,13 @@ def main():
     
     setup_cmdline_args_for_docly_gen(parser)
     args = parser.parse_args()
+    
+    if args.run_on_notebooks:
+        print_on_console("You have mentioned the `run_on_notebooks` switch. It is experimental", color="red", emoji="rotating_light")
+        choice = query_yes_no("Do you want to continue?")
+        if not choice:
+            args.run_on_notebooks = False
+
     config = DoclyConfig(args.config_file)
 
     try:
@@ -151,6 +207,6 @@ def main():
     print_on_console("Engine Loaded.", color="green", emoji="heavy_check_mark")
     ts_lib_path = str(ROOT / "tslibs" / tslib_file)
     
-    table_rows, docstr_loc = _process(args, model, tokenizer, ts_lib_path, config)
+    table_rows, docstr_loc, ipynb_files = _process(args, model, tokenizer, ts_lib_path, config)
 
-    _deal_with_result(args, table_rows, docstr_loc)
+    _deal_with_result(args, table_rows, docstr_loc, ipynb_files)
